@@ -1,4 +1,4 @@
-import lazy_import
+import futsu.lazy_import
 import os
 
 name = 'futsu'
@@ -12,8 +12,8 @@ DEFAULT_LAZY_ENABLE_SET = set([
 def env_lazy_import(env_var, module_name):
     if env_var in os.environ:
         if os.environ[env_var].lower() in ['0', 'false']:
-            return None
+            return futsu.lazy_import.fake_import()
     else:
         if env_var not in DEFAULT_LAZY_ENABLE_SET:
-            return None
-    return lazy_import.lazy_module(module_name)
+            return futsu.lazy_import.fake_import()
+    return futsu.lazy_import.lazy_import(module_name)
