@@ -1,10 +1,10 @@
 import futsu
 import futsu.aws as faws
-import lazy_import
+import futsu.lazy_import
 import re
-boto3 = futsu.env_lazy_import('FUTSU_AWS_ENABLE', 'boto3')
-io = lazy_import.lazy_module('io')
-botocore_exceptions = futsu.env_lazy_import('FUTSU_AWS_ENABLE', 'botocore.exceptions')
+boto3_li = futsu.env_lazy_import('FUTSU_AWS_ENABLE', 'boto3')
+io_li = futsu.lazy_import.lazy_import('io')
+botocore_exceptions_li = futsu.env_lazy_import('FUTSU_AWS_ENABLE', 'botocore.exceptions')
 
 BUCKET_PATH_FORMAT = 's3://([^/]+)/?'
 BUCKET_PATH_FORMAT_RE = None
@@ -60,7 +60,7 @@ def create_client(region_name=None):
     if region_name is None:
         if faws.default_region_name is not None:
             region_name = faws.default_region_name
-    return boto3.client('s3')
+    return boto3_li.load().client('s3')
 
 # def bucket(gs_path, client):
 #    bucket_name = prase_bucket_path(gs_path)
@@ -91,7 +91,7 @@ def blob_to_file(dst, src, client):
 
 def bytes_to_blob(dst, bytes, client):
     dst_bucket_name, dst_object_key = prase_blob_path(dst)
-    with io.BytesIO(bytes) as bout:
+    with io_li.load().BytesIO(bytes) as bout:
         client.upload_fileobj(
             Fileobj=bout,
             Bucket=dst_bucket_name,
@@ -101,7 +101,7 @@ def bytes_to_blob(dst, bytes, client):
 
 def blob_to_bytes(src, client):
     src_bucket_name, src_object_key = prase_blob_path(src)
-    with io.BytesIO() as bin:
+    with io_li.load().BytesIO() as bin:
         client.download_fileobj(
             Fileobj=bin,
             Bucket=src_bucket_name,
@@ -120,6 +120,7 @@ def blob_to_string(src, client):
 
 
 def is_blob_exist(path, client):
+    botocore_exceptions = botocore_exceptions_li.load()
     bucket_name, object_key = prase_blob_path(path)
     try:
         client.head_object(
@@ -131,7 +132,7 @@ def is_blob_exist(path, client):
         if e.response['Error']['Code'] == '404':
             return False
         raise e
-    assert(False)
+    assert (False)
 
 
 def blob_rm(path, client):
