@@ -1,17 +1,21 @@
 import futsu
-import lazy_import
+import futsu.lazy_import
 import os
 
-fgcpstorage = lazy_import.lazy_module('futsu.gcp.storage')
-gcstorage = futsu.env_lazy_import('FUTSU_GCP_ENABLE', 'google.cloud.storage')
-fs3 = lazy_import.lazy_module('futsu.aws.s3')
-ffs = lazy_import.lazy_module('futsu.fs')
-urllib_request = lazy_import.lazy_module('urllib.request')
-shutil = lazy_import.lazy_module('shutil')
+fgcpstorage_li = futsu.lazy_import.lazy_import('futsu.gcp.storage')
+gcstorage_li = futsu.env_lazy_import('FUTSU_GCP_ENABLE', 'google.cloud.storage')
+fs3_li = futsu.lazy_import.lazy_import('futsu.aws.s3')
+ffs_li = futsu.lazy_import.lazy_import('futsu.fs')
+urllib_request_li = futsu.lazy_import.lazy_import('urllib.request')
+shutil_li = futsu.lazy_import.lazy_import('shutil')
 
 
 def local_to_path(dst, src):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
+    ffs = ffs_li.load()
     if fgcpstorage.is_blob_path(dst):
+        gcstorage = gcstorage_li.load()
         gcs_client = gcstorage.client.Client()
         fgcpstorage.file_to_blob(dst, src, gcs_client)
         return
@@ -23,7 +27,11 @@ def local_to_path(dst, src):
 
 
 def path_to_local(dst, src):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
+    ffs = ffs_li.load()
     if fgcpstorage.is_blob_path(src):
+        gcstorage = gcstorage_li.load()
         gcs_client = gcstorage.client.Client()
         fgcpstorage.blob_to_file(dst, src, gcs_client)
         return
@@ -32,14 +40,20 @@ def path_to_local(dst, src):
         fs3.blob_to_file(dst, src, client)
         return
     if src.startswith('https://') or src.startswith('http://'):
+        urllib_request = urllib_request_li.load()
         with urllib_request.urlopen(src) as w_in, open(dst, 'wb') as f_out:
+            shutil = shutil_li.load()
             shutil.copyfileobj(w_in, f_out)
         return
     ffs.cp(dst, src)
 
 
 def bytes_to_path(dst, bytes):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
+    ffs = ffs_li.load()
     if fgcpstorage.is_blob_path(dst):
+        gcstorage = gcstorage_li.load()
         gcs_client = gcstorage.client.Client()
         fgcpstorage.bytes_to_blob(dst, bytes, gcs_client)
         return
@@ -51,20 +65,28 @@ def bytes_to_path(dst, bytes):
 
 
 def path_to_bytes(src):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
+    ffs = ffs_li.load()
     if fgcpstorage.is_blob_path(src):
+        gcstorage = gcstorage_li.load()
         gcs_client = gcstorage.client.Client()
         return fgcpstorage.blob_to_bytes(src, gcs_client)
     if fs3.is_blob_path(src):
         client = fs3.create_client()
         return fs3.blob_to_bytes(src, client)
     if src.startswith('https://') or src.startswith('http://'):
+        urllib_request = urllib_request_li.load()
         with urllib_request.urlopen(src) as w_in:
             return w_in.read()
     return ffs.file_to_bytes(src)
 
 
 def is_blob_exist(p):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
     if fgcpstorage.is_blob_path(p):
+        gcstorage = gcstorage_li.load()
         gcs_client = gcstorage.client.Client()
         return fgcpstorage.is_blob_exist(p, gcs_client)
     if fs3.is_blob_path(p):
@@ -74,7 +96,10 @@ def is_blob_exist(p):
 
 
 def rm(p):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
     if fgcpstorage.is_blob_path(p):
+        gcstorage = gcstorage_li.load()
         gcs_client = gcstorage.client.Client()
         return fgcpstorage.blob_rm(p, gcs_client)
     if fs3.is_blob_path(p):
@@ -84,7 +109,11 @@ def rm(p):
 
 
 def find(p):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
+    ffs = ffs_li.load()
     if fgcpstorage.is_blob_path(p):
+        gcstorage = gcstorage_li.load()
         gcs_client = gcstorage.client.Client()
         return fgcpstorage.find_blob_itr(p, gcs_client)
     if fs3.is_blob_path(p):
@@ -94,6 +123,8 @@ def find(p):
 
 
 def join(*args):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
     if fgcpstorage.is_path(args[0]):
         return fgcpstorage.join(*args)
     if fs3.is_path(args[0]):
@@ -104,6 +135,8 @@ def join(*args):
 
 
 def split(p):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
     if fgcpstorage.is_path(p):
         return fgcpstorage.split(p)
     if fs3.is_path(p):
@@ -114,6 +147,8 @@ def split(p):
 
 
 def basename(p):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
     if fgcpstorage.is_path(p):
         return fgcpstorage.basename(p)
     if fs3.is_path(p):
@@ -124,6 +159,8 @@ def basename(p):
 
 
 def dirname(p):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
     if fgcpstorage.is_path(p):
         return fgcpstorage.dirname(p)
     if fs3.is_path(p):
@@ -134,7 +171,10 @@ def dirname(p):
 
 
 def rmtree(p):
+    fgcpstorage = fgcpstorage_li.load()
+    fs3 = fs3_li.load()
     if fgcpstorage.is_path(p):
+        gcstorage = gcstorage_li.load()
         gcs_client = gcstorage.client.Client()
         fgcpstorage.rmtree(p, gcs_client)
     if fs3.is_path(p):
@@ -142,4 +182,5 @@ def rmtree(p):
         fs3.rmtree(p, client)
     if p.startswith('https://') or p.startswith('http://'):
         raise Exception('CVALHPEH http(s) not support rmtree')
+    shutil = shutil_li.load()
     shutil.rmtree(p, ignore_errors=True)
